@@ -1,3 +1,4 @@
+import re
 import datetime
 
 from django.utils.translation import ugettext_lazy as _
@@ -5,9 +6,9 @@ from django.utils.translation import ugettext_lazy as _
 
 PROTOCOLS = (
     ("internal", _("internal")),
-    ("http", "http"),
-    ("https", "https"),
-    ("ftp", "ftp"),
+    ("external", _("external")),
+    ("mailto", _("mailto")),
+    ("picture", _("picture")),
 )
 
 def is_link_expired(link_expired):
@@ -29,3 +30,12 @@ def set_default_link_expired_date():
     # maybe could be set up of a fix date
     date_in_the_future = datetime.datetime.now() + datetime.timedelta(days=365000)
     return date_in_the_future   
+
+def is_integer(integer_value):
+    """Pseudo interger testing."""
+    if not re.match(r"[0-9]+", integer_value):
+        return False
+    else:
+        return True
+
+   
